The replacement values correspond to the edges of the available coordinate space
discretize(coord_values, xrange, yrange)numeric. The coordinate x and y values, potentially containing Inf or -Inf
Numeric vector of length 2, minimum and maximum values in the x direction
Numeric vector of length 2, minimum and maximum values in the y direction