Convert data coordinates to npc coordinates.
# S3 method for ggtikzCanvas
gg_to_npc(self, coord, panelx, panely, ...)The input coordinates from coord converted to npc coordinates in
the form of a numeric vector of length 2. (0,0) corresponds to the lower
left corner of the viewport containing the ggplot panel specified by
panelx and panely, and (1,1) corresponds to the upper right corner.
a ggtikzCanvas object
A numeric vector of length 2, with the x coordinate to convert
at coord[1] and the y coordinate to convert at coord[2]
X position (column) of the panel holding the data
X position (row) of the panel holding the data
unused