Learn R Programming

ggtikz (version 0.1.5)

unclip: knitr hook to remove clipping from plots produced with the tikzDevice.

Description

Note that the chunk options unclip = TRUE and external = FALSEmust be set for the hook to come into effect!

Usage

unclip(before, options)

Value

Called for side effect. The files containing tikz plots are edited and overwritten.

Arguments

before

see knit_hooks

options

see knit_hooks

See Also

set_ggtikz_unclip_hook to set the knitr hook.

unclip_tikz, the workhorse function for this hook.