Infinite values are replaced with the minimum or maximum value of the padding in the x or y direction, respectively. Additionally, the adjusted coordinate is padded so that it lies just next to the panel borders and axis lines without overlap.
uninfinite_coord(coord, xrange, yrange)uninfinite_tikz(tikz_code, xrange, yrange)
The adjusted TikZ coordinate with padding, as a string.
TikZ coordinate
Numeric vector of length 2, minimum and maximum values in the x direction
Numeric vector of length 2, minimum and maximum values in the y direction
The TikZ code to replace Infinite values in.