powered by
Note that the chunk options unclip = TRUE and external = FALSEmust be set for the hook to come into effect!
unclip = TRUE
external = FALSE
unclip(before, options)
Called for side effect. The files containing tikz plots are edited and overwritten.
see knit_hooks
knit_hooks
set_ggtikz_unclip_hook to set the knitr hook.
set_ggtikz_unclip_hook
unclip_tikz, the workhorse function for this hook.
unclip_tikz